@@ -1,4 +1,4 @@
-# $Id$
+# $Id: ExecuteArray.pm 15242 2012-03-19 10:39:26Z mjevans $
 package ExecuteArray;
 use Test::More;
 use Data::Dumper;
@@ -129,34 +129,22 @@ sub check_tuple_status
     my ($self, $tsts, $expected) = @_;
 
     note(Data::Dumper->Dump([$tsts], [qw(ArrayTupleStatus)]));
-
-    BAIL_OUT('expected data must be specified')
-        if (!$expected || (ref($expected) ne 'ARRAY'));
-
-    is(ref($tsts), 'ARRAY', 'tuple status is an array') or return;
-    if (!is(scalar(@$tsts), scalar(@$expected), 'status arrays same size')) {
-        diag(Dumper($tsts));
-        diag(Dumper($expected));
-        return;
-    }
-
     my $row = 0;
-    foreach my $s (@$expected) {
-        if (ref($s)) {
+    foreach my $s (@$tsts) {
+        if (ref($expected->[$row])) {
             unless ($self->{_param_array_row_counts} == 2) {
-                is(ref($tsts->[$row]), 'ARRAY', 'array in array tuple status');
-                is(scalar(@{$tsts->[$row]}), 3, '3 elements in array tuple status error');
+                is(ref($s), 'ARRAY', 'array in array tuple status');
+                is(scalar(@$s), 3, '3 elements in array tuple status error');
             }
         } else {
-            if ($tsts->[$row] == -1) {
+            if ($s == -1) {
                 pass("row $row tuple status unknown");
             } else {
-                is($tsts->[$row], $s, "row $row tuple status");
+                is($s, $expected->[$row], "row $row tuple status");
             }
         }
-        $row++;
+        $row++
     }
-    return;
 }
 
 # insert might return 'mas' which means the caller said the test
@@ -192,54 +180,49 @@ sub insert
     }
 
     my (@tuple_status, $sts, $total_affected);
-    my $tuple_status_arg = {};
-    $tuple_status_arg->{ArrayTupleStatus} = \@tuple_status unless $ref->{notuplestatus};
-
     $sts = 999999;              # to ensure it is overwritten
     $total_affected = 999998;
     if ($ref->{array_context}) {
         eval {
             if ($ref->{params}) {
                 ($sts, $total_affected) =
-                    $sth->execute_array($tuple_status_arg,
+                    $sth->execute_array({ArrayTupleStatus => \@tuple_status},
                                         @{$ref->{params}});
             } elsif ($ref->{fetch}) {
                 ($sts, $total_affected) =
                     $sth->execute_array(
-                        {%{$tuple_status_arg},
+                        {ArrayTupleStatus => \@tuple_status,
                          ArrayTupleFetch => $ref->{fetch}});
             } else {
                 ($sts, $total_affected) =
-                    $sth->execute_array($tuple_status_arg);
+                    $sth->execute_array({ArrayTupleStatus => \@tuple_status});
             }
         };
     } else {
         eval {
             if ($ref->{params}) {
                 $sts =
-                    $sth->execute_array($tuple_status_arg,
+                    $sth->execute_array({ArrayTupleStatus => \@tuple_status},
                                         @{$ref->{params}});
             } else {
                 $sts =
-                    $sth->execute_array($tuple_status_arg);
+                    $sth->execute_array({ArrayTupleStatus => \@tuple_status});
             }
         };
     }
-    my $ev = $@;
     if ($ref->{error} && $ref->{raise}) {
-        ok($ev, 'error in execute_array eval');
-    } elsif ($ref->{requires_mas} && $ev) {
-        diag("\nThis test died with $ev");
-        diag("It requires multiple active statement support in the driver and I cannot easily determine if your driver supports MAS. Ignoring the rest of this test.");
-        foreach (@tuple_status) {
-            if (ref($_)) {
-                diag(join(",", @$_));
-            }
-        }
-        return 'mas';
-    } elsif ($ref->{raise} && $ev) {
-        BAIL_OUT("Totally unexpected error - $ev");
+        ok($@, 'error in execute_array eval');
     } else {
+        if ($ref->{requires_mas} && $@) {
+            diag("\nThis test died with $@");
+            diag("It requires multiple active statement support in the driver and I cannot easily determine if your driver supports MAS. Ignoring the rest of this test.");
+            foreach (@tuple_status) {
+                if (ref($_)) {
+                    diag(join(",", @$_));
+                }
+            }
+            return 'mas';
+        }
         ok(!$@, 'no error in execute_array eval') or note($@);
     }
     $dbh->commit if $ref->{commit};
@@ -265,7 +248,7 @@ sub insert
         is(scalar(@tuple_status), (($ref->{sts} eq '0E0') ? 0 : $ref->{sts}),
            "$ref->{sts} rows in tuple_status");
     }
-    if ($ref->{tuple} && !exists($ref->{notuplestatus})) {
+    if ($ref->{tuple}) {
         $self->check_tuple_status(\@tuple_status, $ref->{tuple});
     }
     return;
